pub fn make_connector() -> Result<MakeRustlsConnect>Expand description
Build a rustls connector loading the OS trust store.
Installs the ring crypto provider as the process default on first call (idempotent — a second install is ignored).
pub fn make_connector() -> Result<MakeRustlsConnect>Build a rustls connector loading the OS trust store.
Installs the ring crypto provider as the process default on first call (idempotent — a second install is ignored).